
```bash
uv build
# 会在 dist/ 目录下生成两个文件 .tar.gz 文件（源码分发包) .whl 文件（二进制分发包，也叫 Wheel）
twine upload dist/*
# 注意清理旧的文件
```

```txt
🧹 优化/重构
📝 更新文档
🐛 修复 Bug
🔥 移除代码或文件
♻️ 重构代码
✨ 添加新功能
```

## [v0.1.4] - 2025-10-17
### ♻️ 优化/重构
- 调整 `log_manager` 模块结构

## [v0.1.5] [v0.1.6] - 2025-10-17
### ♻️ 调整结构
- 调整 整体结构， 修复 v0.1.4 不可用效果

## [v0.1.7] - 2025-10-28
### ✨ 添加新功能 🐛 修改Bug
- 调整 时间轮询基准时间(从 UTC 改成 本地时间)
- 新增 * *, 轮询时间和文件大小(默认按 1天 5M)

## [v2025.12.03]
- 🐛 删除 时间轮询方式
- 🐛 修改 文件大小轮询方式

## [v2025.12.11]
- ✨ 重新添加 时间轮询方式，添加测试